==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/zh/issues.php <==
<?php
regGS("Issue List", "");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "名称");
regGS("Front Page Template<BR><SMALL>(click to change)</SMALL>", "首页模版");
regGS("Single Article Template<BR><SMALL>(click to change)</SMALL>", "单文章模版（单击进行修改）");
regGS("Published<BR><SMALL>(yyyy-mm-dd)</SMALL>", "已发布(yyyy-mm-dd)");
regGS("Delete issue $1", "删除议题$1");
regGS("Change issue status", "改变议题状态");
regGS("You do not have the right to change issues.", "您无权改变议题");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "你确认要把议题$1的状态从$2改成$3?");
regGS("Changing issue status", "正在改变议题状态");
regGS("Status of the issue $1 has been changed from $2 to $3", "议题$1的状态已从$2改成$3");
regGS("Status of the issue $1 could not be changed.", "议题$1的状态不能改变");
regGS("Add new translation", "添加新翻译");
regGS("You do not have the right to add issues.", "您无权增加议题");
regGS("The issue $1 has been successfuly added.", "议题$1已成功添加");
regGS("The issue could not be added.", "议题不能被添加");
regGS("Please check if another issue with the same number/language does not already exist.", "请确认是否其它同意数字/语言的议题还没存在");
regGS("Change issue details", "改变议题详情");
regGS("You do not have the right to change issue details.", "你无权修改议题详情");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "");
regGS("Updating issue", "正在更新议题");
regGS("Changing issue's details", "正在改变议题详情");
regGS("The issue $1 has been successfuly changed.", "议题$1已被成功修改");
regGS("The issue could not be changed.", "议题不能被修改");
regGS("Issue $1 updated in publication $2", "议题$1在发布$2中已更新");
regGS("You do not have the right to delete issues.", "您无权删除议题");
regGS("Are you sure you want to delete the issue $1?", "你确认删除议题$1");
regGS("Deleting issue", "正在删除议题");
regGS("Use the structure of the previous issue", "用以前议题的结构");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "除内容外，复制所有语言先前议题的完整结构");
regGS("You may modify it later if you wish.", "如果您愿意，可以以后再修改");
regGS("Create a new structure", "创建新结构");
regGS("Create a complete new structure.", "创建全新的结构");
regGS("You must define an issue type for each language and then sections for them.", "你必须为每种语言定义一个议题，然后是区");
regGS("Copy previous issue", "复制以前的议题");
regGS("No previous issue.", "无以前的议题");
regGS("Copy structure from issue nr $1", "从$1议题复制结构");
regGS("Copying previous issue", "正在复制以前的议题");
regGS("Select the issue", "选择议题");
regGS("New issue $1 from $2 in publication $3", "在发布$3来自$2的新议题$1");
regGS("Adding new issue", "正在增加新议题");
regGS("Preview issue", "预览议题");
regGS("This issue cannot be previewed. Please make sure it has a $1 template selected.", "此议题不能被预览，请确认它选择$1模版");
regGS("front page", "首页");
regGS("Changing issue template", "改变议题模版");
regGS("You do not have the right to change issue templates.", "您无权改变议题模版");
regGS("Changing issue template for front page", "从首页正在改变议题模版");
regGS("Changing issue template for single article", "正在从单文章改变议题模版");
regGS("The template has been successfully changed.", "模版已被成功修改");
regGS("Issue template for publication $1 changed to $2", "议题模版从发布$1变化到$2");
regGS("Issue template for single articles from $1 changed to $2", "单文章的模版从$1改变到$2");
regGS("The template could not be changed.", "模版不能被改变");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/zh/issues.php <==
<?php 
regGS("Change issue status", "");
regGS("The values you are trying to set conflict with issue \"$1$2. $3 ($4)$5\".", "");
regGS("The number must be unique for each issue in this publication of the same language.", "");
regGS("The language and URL name must be unique for each issue in this publication.", "");
regGS("Issue created.", "");
regGS("Issue updated", "");
regGS("Could not save the changes to the issue.", "");
regGS("Unpublish on: $1", "");
regGS("There are $1 articles in this issue.", "");
regGS("The issue $1 has been deleted.", "");
regGS("Schedule", "");
regGS("Publish on: $1", "");
regGS("Publish Date $1", "");
regGS("Deleted issue", "");
regGS("Delete issue", "");
regGS("Click here to publish this issue", "");
regGS("A total of $1 articles were deleted.", "");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "名称");
regGS("Front Page Template<BR><SMALL>(click to change)</SMALL>", "首页模版");
regGS("Single Article Template<BR><SMALL>(click to change)</SMALL>", "单文章模版（单击进行修改）");
regGS("Delete issue $1", "删除议题$1");
regGS("You do not have the right to change issues.", "您无权改变议题");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "你确认要把议题$1的状态从$2改成$3?");
regGS("Changing issue status", "正在改变议题状态");
regGS("Status of the issue $1 has been changed from $2 to $3", "议题$1的状态已从$2改成$3");
regGS("Status of the issue $1 could not be changed.", "议题$1的状态不能改变");
regGS("Add new translation", "添加新翻译");
regGS("You do not have the right to add issues.", "您无权增加议题");
regGS("The issue $1 has been successfuly added.", "议题$1已成功添加");
regGS("The issue could not be added.", "议题不能被添加");
regGS("Change issue details", "改变议题详情");
regGS("You do not have the right to change issue details.", "你无权修改议题详情");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "");
regGS("Updating issue", "正在更新议题");
regGS("Changing issue's details", "正在改变议题详情");
regGS("The issue $1 has been successfuly changed.", "议题$1已被成功修改");
regGS("The issue could not be changed.", "议题不能被修改");
regGS("Issue $1 updated in publication $2", "议题$1在发布$2中已更新");
regGS("You do not have the right to delete issues.", "您无权删除议题");
regGS("Are you sure you want to delete the issue $1?", "你确认删除议题$1");
regGS("Use the structure of the previous issue", "用以前议题的结构");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "除内容外，复制所有语言先前议题的完整结构");
regGS("You may modify it later if you wish.", "如果您愿意，可以以后再修改");
regGS("Create a new structure", "创建新结构");
regGS("Create a complete new structure.", "创建全新的结构");
regGS("You must define an issue type for each language and then sections for them.", "你必须为每种语言定义一个议题，然后是区");
regGS("Copy previous issue", "复制以前的议题");
regGS("No previous issue.", "无以前的议题");
regGS("Copy structure from issue number $1", "从$1议题复制结构");
regGS("New issue $1 from $2 in publication $3", "在发布$3来自$2的新议题$1");
regGS("Preview issue", "预览议题");
regGS("This issue cannot be previewed. Please make sure it has a $1 template selected.", "此议题不能被预览，请确认它选择$1模版");
regGS("front page", "首页");
regGS("Changing issue template", "改变议题模版");
regGS("You do not have the right to change issue templates.", "您无权改变议题模版");
regGS("Changing issue template for front page", "从首页正在改变议题模版");
regGS("Changing issue template for single article", "正在从单文章改变议题模版");
regGS("The template has been successfully changed.", "模版已被成功修改");
regGS("Issue template for publication $1 changed to $2", "议题模版从发布$1变化到$2");
regGS("Issue template for single articles from $1 changed to $2", "单文章的模版从$1改变到$2");
regGS("The template could not be changed.", "模版不能被改变");
regGS("There was an error reading the language parameter.", "");
regGS("There was an error reading the publication parameter.", "");
regGS("There was an error reading the issue parameter.", "");
regGS("There was an error scheduling the $1 action on $2", "");
regGS("The action scheduled on $1 could not be deleted.", "");
?>
